@@ -1,7 +1,7 @@
 """
 Help?
 """
-__version__ = '1.0'
+__version__ = '1.1'
 
 
 def test():
@@ -19,7 +19,7 @@ import sys
 # Import package modules
 from . import assumptions, astroclasses, astroquantities, equations, example, flags, plots
 # import OEC database
-from .database import OECDatabase
+from .database import OECDatabase, load_db_from_url
 
 
 
